@@ -67,7 +67,7 @@ class SQLAlchemyAsyncMockRepository(SQLAlchemyAsyncRepositoryProtocol[ModelT]):
         "auto_commit",
         "attribute_names",
         "with_for_update",
-        "force_basic_query_mode",
+        "count_with_window_function",
         "loader_options",
         "execution_options",
         "order_by",
@@ -698,7 +698,7 @@ class SQLAlchemyAsyncMockRepository(SQLAlchemyAsyncRepositoryProtocol[ModelT]):
         *filters: Union[StatementFilter, ColumnElement[bool]],
         statement: Union[Select[tuple[ModelT]], StatementLambdaElement, None] = None,
         auto_expunge: Optional[bool] = None,
-        force_basic_query_mode: Optional[bool] = None,
+        count_with_window_function: Optional[bool] = None,
         order_by: Union[list[OrderingPair], OrderingPair, None] = None,
         error_messages: Union[ErrorMessages, None, EmptyType] = Empty,
         load: Optional[LoadSpec] = None,
