@@ -3,12 +3,13 @@
 
 from __future__ import annotations
 
+from collections.abc import Generator, Sequence
 from pathlib import Path
-from typing import Generator, Sequence
 
 import pytest
 from flask import Flask, Response
 from msgspec import Struct
+from pydantic import BaseModel
 from sqlalchemy import String, select, text
 from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.orm import DeclarativeBase, Mapped, Session, mapped_column
@@ -47,6 +48,12 @@ class UserSchema(Struct):
     name: str
 
 
+class UserPydantic(BaseModel):
+    """Test user pydantic model."""
+
+    name: str
+
+
 class UserService(SQLAlchemySyncRepositoryService[User], FlaskServiceMixin):
     """Test user service."""
 
@@ -109,8 +116,9 @@ def test_sync_extension_init_with_app(setup_database: Path) -> None:
 def test_sync_extension_multiple_init(setup_database: Path) -> None:
     app = Flask(__name__)
 
-    with app.app_context(), pytest.raises(
-        ImproperConfigurationError, match="Advanced Alchemy extension is already registered"
+    with (
+        app.app_context(),
+        pytest.raises(ImproperConfigurationError, match="Advanced Alchemy extension is already registered"),
     ):
         config = SQLAlchemySyncConfig(connection_string=f"sqlite:///{setup_database}", metadata=metadata)
         extension = AdvancedAlchemy(config, app)
@@ -160,8 +168,9 @@ def test_async_extension_init_with_app(setup_database: Path) -> None:
 def test_async_extension_multiple_init(setup_database: Path) -> None:
     app = Flask(__name__)
 
-    with app.app_context(), pytest.raises(
-        ImproperConfigurationError, match="Advanced Alchemy extension is already registered"
+    with (
+        app.app_context(),
+        pytest.raises(ImproperConfigurationError, match="Advanced Alchemy extension is already registered"),
     ):
         config = SQLAlchemyAsyncConfig(
             connection_string=f"sqlite+aiosqlite:///{setup_database}", bind_key="async", metadata=metadata
@@ -281,12 +290,14 @@ def test_sync_autocommit(setup_database: Path) -> None:
         assert result.scalar_one().name == "test"
 
 
-def test_sync_autocommit_with_redirect(setup_database: Path) -> None:
+def test_sync_autocommit_include_redirect(setup_database: Path) -> None:
     app = Flask(__name__)
 
     with app.test_client() as client:
         config = SQLAlchemySyncConfig(
-            connection_string=f"sqlite:///{setup_database}", commit_mode="autocommit_with_redirect", metadata=metadata
+            connection_string=f"sqlite:///{setup_database}",
+            commit_mode="autocommit_include_redirect",
+            metadata=metadata,
         )
 
         extension = AdvancedAlchemy(config, app)
@@ -298,7 +309,7 @@ def test_sync_autocommit_with_redirect(setup_database: Path) -> None:
             session.add(User(name="test_redirect"))
             return "", 302, {"Location": "/redirected"}
 
-        # Test redirect response (should commit with AUTOCOMMIT_WITH_REDIRECT)
+        # Test redirect response (should commit with autocommit_include_redirect)
         response = client.post("/test")
         assert response.status_code == 302
 
@@ -366,13 +377,13 @@ def test_async_autocommit(setup_database: Path) -> None:
     extension.portal_provider.stop()
 
 
-def test_async_autocommit_with_redirect(setup_database: Path) -> None:
+def test_async_autocommit_include_redirect(setup_database: Path) -> None:
     app = Flask(__name__)
 
     with app.test_client() as client:
         config = SQLAlchemyAsyncConfig(
             connection_string=f"sqlite+aiosqlite:///{setup_database}",
-            commit_mode="autocommit_with_redirect",
+            commit_mode="autocommit_include_redirect",
             metadata=metadata,
         )
         extension = AdvancedAlchemy(config, app)
@@ -385,7 +396,7 @@ def test_async_autocommit_with_redirect(setup_database: Path) -> None:
             session.add(user)
             return "", 302, {"Location": "/redirected"}
 
-        # Test redirect response (should commit with AUTOCOMMIT_WITH_REDIRECT)
+        # Test redirect response (should commit with autocommit_include_redirect)
         response = client.post("/test")
         assert response.status_code == 302
         session = extension.get_session()
@@ -542,7 +553,7 @@ def test_async_portal_explicit_stop_with_commit(setup_database: Path) -> None:
     extension.portal_provider.stop()
 
 
-def test_sync_service_jsonify(setup_database: Path) -> None:
+def test_sync_service_jsonify_msgspec(setup_database: Path) -> None:
     app = Flask(__name__)
 
     with app.test_client() as client:
@@ -569,7 +580,7 @@ def test_sync_service_jsonify(setup_database: Path) -> None:
         assert result.scalar_one().name == "service_test"
 
 
-def test_async_service_jsonify(setup_database: Path) -> None:
+def test_async_service_jsonify_msgspec(setup_database: Path) -> None:
     app = Flask(__name__)
 
     with app.test_client() as client:
@@ -597,3 +608,61 @@ def test_async_service_jsonify(setup_database: Path) -> None:
         assert result
         assert result.name == "async_service_test"
     extension.portal_provider.stop()
+
+
+def test_sync_service_jsonify_pydantic(setup_database: Path) -> None:
+    app = Flask(__name__)
+
+    with app.test_client() as client:
+        config = SQLAlchemySyncConfig(
+            connection_string=f"sqlite:///{setup_database}", metadata=metadata, commit_mode="autocommit"
+        )
+        extension = AdvancedAlchemy(config, app)
+
+        @app.route("/test", methods=["POST"])
+        def test_route() -> Response:
+            service = UserService(extension.get_sync_session())
+            user = service.create({"name": "test_sync_service_jsonify_pydantic"})
+            return service.jsonify(service.to_schema(user, schema_type=UserPydantic))
+
+        # Test successful response (should commit)
+        response = client.post("/test")
+        assert response.status_code == 200
+
+        # Verify the data was committed
+        session = extension.get_session()
+        assert isinstance(session, Session)
+        result = session.execute(select(User).where(User.name == "test_sync_service_jsonify_pydantic"))
+        assert result.scalar_one().name == "test_sync_service_jsonify_pydantic"
+
+
+def test_async_service_jsonify_pydantic(setup_database: Path) -> None:
+    app = Flask(__name__)
+
+    with app.test_client() as client:
+        config = SQLAlchemyAsyncConfig(
+            connection_string=f"sqlite+aiosqlite:///{setup_database}", metadata=metadata, commit_mode="autocommit"
+        )
+        extension = AdvancedAlchemy(config, app)
+
+        @app.route("/test", methods=["POST"])
+        def test_route() -> Response:
+            service = AsyncUserService(extension.get_async_session())
+            user = extension.portal_provider.portal.call(
+                service.create, {"name": "test_async_service_jsonify_pydantic"}
+            )
+            return service.jsonify(service.to_schema(user, schema_type=UserPydantic))
+
+        # Test successful response (should commit)
+        response = client.post("/test")
+        assert response.status_code == 200
+
+        # Verify the data was committed
+        session = extension.get_session()
+        assert isinstance(session, AsyncSession)
+        result = extension.portal_provider.portal.call(
+            session.scalar, select(User).where(User.name == "test_async_service_jsonify_pydantic")
+        )
+        assert result
+        assert result.name == "test_async_service_jsonify_pydantic"
+    extension.portal_provider.stop()
